# Porphyry

The library for convenient exploratory data analysis, completing, tuning and deployment machine learning models in working environment using PI-system data storage. Applying of basic algorithms for gas wells current flow prediction based on indirect technological parameters.

- flexible extraction of historical data; 
- receiving current values; 
- machine learning models prediction based on current or historical data; 
- automatic updating of machine learning models; 
- tracking of machine learning models metrics; 
- gas flow distribution along the wells; 
- sending notifications.